#!/usr/bin/python
# Gabriel Fernandes <gabrielfernndss@gmail.com>


import re
import os
import sys
import shutil
import zipfile

py_version = sys.version_info.major

if py_version == 2:
    import retrievedata
else:
    from . import retrievedata


"""
Algumas funcoes de
utilidade na automatizacao
"""


MATRICULA_PATTERN = re.compile('INSIRA SEU NUMERO DE MATRICULA')
ROTEIRO_PATTERN = re.compile('R0.-0.')


def valida_turma(turma):
    if not isinstance(turma, str):
        raise TypeError('turma precisa ser um caractere("str")')
    turmas = ('1', '2', '3')
    if turma not in turmas:
        raise ValueError('turma precisa ser uma das: (1,2,3)')


def valida_matricula(matricula):
    if not isinstance(matricula, str):
        raise TypeError('matricula precisa ser uma "str"')
    regex = re.compile('\d{1,9}\Z')
    if not regex.match(matricula):
        raise ValueError('matricula precisa ser do tipo xxxxxxxxx, onde x eh um digito(1-9)')


def valida_path(path):
    if not isinstance(path, str):
        raise TypeError('path precisa ser passado como uma "str"')
    if not os.path.isdir(path):
        raise TypeError('insira um caminho("path") de diretorio valido')


def write_pom(path, matricula, roteiro):
    valida_path(path)
    valida_matricula(matricula)
    retrievedata.valida_roteiro(roteiro)

    data = None
    with open(path + '/pom.xml', 'r') as pom:
        data = pom.read()
        data = MATRICULA_PATTERN.sub(matricula, data)
        data = ROTEIRO_PATTERN.sub(roteiro, data)

    if data != None:
        with open(path + '/pom.xml', 'w') as pom:
            pom.write(data)


def extract_zip(zip, folder):
    valida_path(os.path.dirname(os.path.abspath(zip)))
    valida_path(os.path.dirname(os.path.abspath(folder)))

    with zipfile.ZipFile(zip) as zp:
        zp.extractall(folder)


def move_folder(folder, path):
    valida_path(folder)
    valida_path(path)

    shutil.move(folder, path)


def mvn_commit(path):
    valida_path(path)

    os.system('cd %s && mvn install -DskipTests' %path)


def rm_zips(path):
    valida_path(path)

    zips = filter(lambda f: f.endswith('.zip'), os.listdir(path))
    zips = list(map(lambda f: os.path.join(path, f), zips))
    return len(list(map(lambda f: os.unlink(f), zips)))


def rm_folders(path):
    valida_path(path)

    folders = list(map(lambda f: os.path.join(path, f), os.listdir(path)))
    folders = filter(lambda f: os.path.isdir(f) and not f.endswith('__pycache__'), folders)
    return len(list(map(lambda f: shutil.rmtree(f), folders)))


def reset_config(path):
    valida_path(path)

    try:
        os.unlink(os.path.join(path, 'personalinfo.json'))
        return 'configuracoes resetadas com sucesso'
    except FileNotFoundError:
        return 'configuracao ainda nao feita'


def main():
    args = sys.argv
    try:
        write_pom(args[1], args[2], args[3])
    except IndexError:
        print('''Uso: passar caminho ate a pasta em que se encontra o pom.xml,
            matricula e roteiro na qual deseja-se preencher automaticamento no pom
            Exemplo: python3 autoit.py /home/fernandes/leda-roteiros 111110234 R03-03''')
        sys.exit(1)


if __name__ == '__main__':
    main()



#!/usr/bin/python
# Gabriel Fernandes <gabrielfernndss@gmail.com>


from __future__ import print_function

import os
import re
import sys
import json
import shutil
from pprint import pprint

py_version = sys.version_info.major

if py_version == 2:
    import autoit
    import retrievedata

    input = raw_input

else:
    from . import autoit
    from . import retrievedata


"""
Controla as funcionalidades
principais
"""


HERE = os.path.dirname(os.path.abspath(__file__))


def set_up():
    data = {}
    validado = False
    print('Primeiro uso detectado...')
    print('...comecando configuracao')

    while True:
        data['nome'] = input('Digite seu nome: ')
        if data['nome'].strip == '':
            print('Voce precisa ter um nome')
            continue
        break

    while True:
        data['turma'] = input('Digite sua turma(1, 2 ou 3): ')
        if data['turma'] not in ('1', '2', '3'):
            print('Sua turma precisa ser 1, 2 ou 3')
            continue
        break

    while True:
        matricula_regex = re.compile(r'\d{9}')
        data['matricula'] = input('Numero de matricula: ')
        if matricula_regex.match(data['matricula']) == None:
            print('Sua matricula precisa ter 9 digitos')
            continue
        break

    while True:
        data['path'] = input('Caminho completo ate sua pasta com roteiros: ')
        if data['path'].strip() == '' or not os.path.isdir(data['path']):
            print('Voce precisa especificar um caminho para sua pasta')
            continue
        validado = True
        break

    if validado:
        with open(os.path.join(HERE, 'personalinfo.json'), 'w') as arq:
            json.dump(data, arq, indent=2)
        print('\nConfiguracao efetuada com sucesso!\n')


def get_personal_info():
    try:
        FileNotFoundError
    except NameError:
        FileNotFoundError = IOError

    try:
        with open(os.path.join(HERE, 'personalinfo.json')) as data:
            if py_version == 2:
                return {a.encode('utf-8'):b.encode('utf-8') for a, b in json.load(data).items()}
            return json.load(data)

    except FileNotFoundError:
        return 'configuracao ainda nao realizada'


def main():
    try:
        if 'personalinfo.json' not in os.listdir(HERE):
            set_up()
            main()
        else:
            if len(sys.argv) > 1:
                command = sys.argv[1]

                if command == 'info':
                    pprint(get_personal_info())
                elif command == 'hora':
                    print(retrievedata.get_hora_atual())
                elif command == 'reset':
                    print(autoit.reset_config(HERE))
                elif command == 'hoje':
                    print(retrievedata.get_roteiro_today(get_personal_info()['turma']))
                elif command == 'cronograma':
                    pprint(retrievedata.req_crono(get_personal_info()['turma']))
                else:
                    print('Como usar',
                                '\n\tsempre que tiver um roteiro para fazer, rode como um modulo python',
                                '\n\te confira na pasta que configurou como a de roteiros',
                                '\n\t(o opcional "-m" para o python significa que voce que rodar como modulo)',
                                '\n\ttambem possivel utilizar sem a etapa de instalacao, para isso',
                                '\n\tclone o repositorio no github e sempre que quiser rodar',
                                '\n\tse dirija ate a pasta automated-leda-tasks e rode como modulo python',
                            '\nInstalar',
                                '\n\tpip install --user automated',
                            '\nRodar',
                                '\n\tpython -m automated',
                                '\n\t(necessario somente essa linha para realizar todo o servico)',
                                '\n\tpython -m automated [opcional]',
                                '\n\t(ou funcionalidades extras com algum opcional)',
                            '\nTambem possivel utilizar de outras aplicacoes',
                                '\n\tfrom automated import [__main__ | autoit | retrievedata]',
                            '\nOpcionais validos via linha de comando',
                                '\n\thelp::          mostra essa mensagem',
                                '\n\thora::          exibe hora segundo o servidor',
                                '\n\thoje::          mostra se existe roteiro para hoje',
                                '\n\tinfo::          exibe informacoes configuradas',
                                '\n\treset::         reseta configuracoes',
                                '\n\tcronograma::    exibe todos os roteiros do periodo'
                        )

            else:
                data = get_personal_info()
                roteiro = retrievedata.match_roteiro(data['turma'])

                if roteiro:
                    print('Roteiro %s disponivel, pegando ele para voce...' %roteiro)
                    retrievedata.get_roteiro_zip(HERE, roteiro, data['matricula'])
                    autoit.extract_zip(os.path.join(HERE, roteiro + '.zip'), os.path.join(HERE, roteiro[0:3]))
                    autoit.rm_zips(HERE)
                    autoit.write_pom(os.path.join(HERE, roteiro[0:3]), data['matricula'], roteiro)
                    try:
                        autoit.move_folder(os.path.join(HERE, roteiro[0:3]), data['path'])
                    except shutil.Error as e:
                        autoit.rm_folders(HERE)

                    print('...enviando com o maven...\n')
                    autoit.mvn_commit(os.path.join(data['path'], roteiro[0:3]))
                    print('\n...trabalho acabado por aqui, roteiro %s' %roteiro,
                            '\nencontra-se em %s' %(data['path'] + '/' + roteiro[0:3]))
                else:
                    print('...sem roteiros disponiveis no momento')

    except KeyboardInterrupt:
        print('\nSaindo...')
        sys.exit(1)


if __name__ == '__main__':
    main()



#!/usr/bin/python
# Gabriel Fernandes <gabrielfernndss@gmail.com>


import re
import os
import sys
import pprint
import datetime

import requests

py_version = sys.version_info.major

if py_version == 2:
    import autoit

else:
    from . import autoit


"""
Acesso ao servidor
"""


URLS = ('http://150.165.85.29:81/cronograma',
        'http://150.165.85.29:81/horaAtual',
        'http://150.165.85.29:81/download')


def make_pattern(turma):
    return re.compile('''(?:P[PRF][1-3]|R(?:0|1(?=[0-7]))\d)-0''' + turma
                    + '''\s*<td\s*class="text-xs-center"\s*data-toggle="tooltip"\s*data-placement="right"\s*title='Atividade'''
                    + '''\s*inicia\s*em\s*\d\d/\d\d/2017\s*\d\d:\d\d''')


def valida_requisicao(req):
    try:
        req.raise_for_status()
    except requests.exceptions.HTTPError as http_error:
        print(http_error)
        sys.exit(1)


def valida_roteiro(roteiro):
    if not isinstance(roteiro, str):
        raise TypeError('roteiro precisa ser uma "str"')
    regex = re.compile('(?:P[PRF][1-3]|R(?:0|1(?=[0-7]))\d)-0[1-3]\Z')
    if not regex.match(roteiro):
        raise ValueError('roteiro precisa ter o seguinte formato: R03-02 ou PP2-3 por exemplo')


def make_datetime(datetime_tuple):
    ano = int(datetime_tuple[0][6:10])
    mes = int(datetime_tuple[0][3:5])
    dia = int(datetime_tuple[0][0:2])
    hora = int(datetime_tuple[1][0:2])
    minutos = int(datetime_tuple[1][3:5])
    return datetime.datetime(ano, mes, dia, hora, minutos)


def get_roteiro_today(turma):
    today = get_datetime_atual()
    all_roteiros = get_roteiros(turma)
    for k in all_roteiros:
        if today.date() == all_roteiros[k].date():
            return k


def match_roteiro(turma):
    today = get_datetime_atual()
    all_roteiros = get_roteiros(turma)
    for k in all_roteiros:
        if today.date() == all_roteiros[k].date() and today.time() >= all_roteiros[k].time():
            return k


def req_crono(turma):
    req = requests.get(URLS[0])
    valida_requisicao(req)
    autoit.valida_turma(turma)

    all_roteiros = make_pattern(turma).findall(req.text)
    roteiros = []
    dates = []
    horas = []
    for i in range(len(all_roteiros)):
        roteiros.append(all_roteiros[i][:6])
        dates.append(all_roteiros[i][-16:-6])
        horas.append(all_roteiros[i][-1:-6:-1][::-1])

    all_roteiros = {str(a):(str(b), str(c)) for a, b, c in ((roteiros[i], dates[i], horas[i]) for i in range(len(roteiros)))}
    return all_roteiros


def get_roteiros(turma):
    all_roteiros = req_crono(turma)
    for k in all_roteiros:
        all_roteiros[k] = make_datetime(all_roteiros[k])
    return all_roteiros


def req_date_hora():
    req = requests.get(URLS[1])
    valida_requisicao(req)
    if py_version == 2:
        return req.text.encode('utf-8')
    else:
        return req.text


def get_datetime_atual():
    return make_datetime((get_date_atual(), get_hora_atual()))


def get_date_atual():
    return req_date_hora()[-19:-9]


def get_hora_atual():
    return req_date_hora()[-8:-3]


def get_roteiro_zip(path, roteiro, matricula):
    valida_roteiro(roteiro)
    autoit.valida_path(path)
    autoit.valida_matricula(matricula)

    data = {'id': roteiro,
            'matricula': matricula}
    req_roteiro = requests.post('http://150.165.85.29:81/download', data=data)
    valida_requisicao(req_roteiro)
    if req_roteiro.text.startswith('Matricula'):
        raise ValueError('matricula nao cadastrada')
    else:
        with open(os.path.join(path, roteiro + '.zip'), 'wb') as zp:
            zp.write(req_roteiro.content)


def main():
    if len(sys.argv) > 1:
        pprint.pprint(req_crono(sys.argv[1]))
    else:
        print('''Voce precisa especificar a turma passando como argumento da linha de comando
            como por exemplo: "python3 retrievedata.py 3" sendo o argumento referente a uma das 3 turmas''')
        sys.exit(1)


if __name__ == '__main__':
    main()



#!/usr/bin/python
# Gabriel Fernandes <gabrielfernndss@gmail.com>

from setuptools import setup


setup(
   name='automated',
   version='1.1.5',
   description='A automated package',
   long_description=open('README.md').read(),
   license='MIT',
   classifiers=[
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
    ],
   url='https://github.com/gabrielfern/automated-leda-tasks',
   author='Gabriel Fernandes',
   author_email='gabrielfernndss@gmail.com',
   packages=['automated'],
   install_requires=['requests', 'setuptools'],
   data_files=[('README.md', ['README.md']),]
)
